@@ -24,6 +24,7 @@ import org.junit.Assert;
 import org.junit.Ignore;
 import org.junit.Test;
 
+import java.util.Collections;
 import java.util.HashSet;
 import java.util.LinkedList;
 import java.util.List;
@@ -559,59 +560,60 @@ public class PushPullBlockingQueueTest {
         Assert.assertEquals(dbq.size(), 128);
     }
 
+    @Test
+    public void testAddAllReturn() {
+
+        final int cap = 8;
+        final BlockingQueue<Integer> dbq = new PushPullBlockingQueue<>(cap);
+
+        final Set<Integer> set = new HashSet();
+
+        for(int i=0; i<8; i++) {
+            set.add(i);
+        }
+
+        Assert.assertTrue(dbq.addAll(set));
+
+        Integer iVal = dbq.poll();
+        while(iVal != null) {
+            Assert.assertTrue(set.contains(iVal));
+            iVal = dbq.poll();
+        }
+
+        for(int i=0; i<20; i++) {
+            set.add(i);
+        }
+
+        // at least one will fail
+        Assert.assertTrue(dbq.addAll(set));
+    }
+
     @Test(expected = UnsupportedOperationException.class)
-    public void testRemoveAll() {
+    public void testRemoveIsNotSupported() {
+        final int cap = 100;
+        final BlockingQueue<Integer> dbq = new PushPullBlockingQueue<Integer>(cap);
+
+        dbq.remove(0);
+    }
+
+    @Test(expected = UnsupportedOperationException.class)
+    public void testRemoveAllIsNotSupported() {
 
         final int cap = 100;
         final BlockingQueue<Integer> dbq = new PushPullBlockingQueue<Integer>(cap);
 
-        Set<Integer> si = new HashSet(cap);
-        for(int i=0; i<cap/10; i++) {
-            si.add(Integer.valueOf(i));
-        }
-        dbq.addAll(si);
-        Assert.assertTrue(dbq.containsAll(si));
-
-        Set<Integer> ni = new HashSet(cap);
-        for(int i=1; i<cap/10; i++) {
-            ni.add(Integer.valueOf(-i));
-        }
-        dbq.addAll(ni);
-        Assert.assertTrue(dbq.containsAll(si));
-        Assert.assertTrue(dbq.containsAll(ni));
-
-
-        dbq.removeAll(si);
-        Assert.assertTrue(dbq.containsAll(ni));
-        Assert.assertFalse(dbq.containsAll(si));
-
-        dbq.removeAll(ni);
-        Assert.assertFalse(dbq.containsAll(ni));
-        Assert.assertFalse(dbq.containsAll(si));
+        dbq.removeAll(Collections.emptySet());
     }
 
     @Test(expected = UnsupportedOperationException.class)
-    public void testRetainAll() {
-
+    public void testRetainAllIsNotSupported() {
         final int cap = 100;
         final BlockingQueue<Integer> dbq = new PushPullBlockingQueue<Integer>(cap);
 
-        for(int i=0; i<cap; i++) {
-            dbq.offer(Integer.valueOf(i));
-        }
-
-        Set<Integer> si = new HashSet(cap);
-        for(int i=0; i<cap/10; i++) {
-            si.add(Integer.valueOf(i));
-        }
-
-        dbq.retainAll(si);
-
-        Assert.assertEquals(cap/10, dbq.size());
-
-        dbq.containsAll(si);
+        dbq.retainAll(Collections.emptySet());
     }
 
+
     @Test(timeout=30000)
     public void testOverflowingOffers() throws InterruptedException {
         // there is a problem in the native implementation
